#
# spec file for package barcode
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           barcode
Version:        0.99
Release:        bp154.2.23
Summary:        Text-Mode Barcode Creation Utility
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Other
URL:            https://www.gnu.org/software/barcode
Source0:        ftp://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.xz
Source1:        ftp://ftp.gnu.org/pub/gnu/%{name}/%{name}-%{version}.tar.xz.sig
Source2:        %{name}.keyring
# PATCH-FIX-OPENSUSE barcode-0.99-info.patch
Patch2:         %{name}-0.99-info.patch
# PATCH-FIX-UPSTREAM barcode-0.98-leak-fix.patch bnc#537525 -- Fix memory leak by adding call to free.
Patch5:         %{name}-0.98-leak-fix.patch
# PATCH-FIX-UPSTREAM barcode-fix-renamed-include.patch malcolmlewis@opensuse.org -- Fix renamed gettext include header reference.
Patch6:         barcode-fix-renamed-include.patch
BuildRequires:  makeinfo
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}

%description
GNU Barcode is meant to meet most barcode creation needs with a
conventional printer. It can create printouts for the conventional
product tagging standards: UPC-A, UPC-E, EAN-13, EAN-8, ISBN, as well
as a few other formats. Output is generated in either PostScript or
Encapsulated PostScript format.

%package devel
Summary:        Text-Mode Barcode Creation Utility - Development files
Group:          Development/Libraries/C and C++

%description devel
GNU Barcode is meant to meet most barcode creation needs with a
conventional printer. It can create printouts for the conventional
product tagging standards: UPC-A, UPC-E, EAN-13, EAN-8, ISBN, as well
as a few other formats. Output is generated in either PostScript or
Encapsulated PostScript format.

%prep
%setup -q
%patch2
%patch5
%patch6 -p1

%build
%global _lto_cflags %{_lto_cflags} -ffat-lto-objects
export CFLAGS="%{optflags} -fcommon"
%configure
%make_build

%install
%make_install
install -Dm0644 barcode.h %{buildroot}%{_includedir}/barcode.h
install -Dm0644 .libs/libbarcode.a %{buildroot}%{_libdir}/libbarcode.a

%post
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%preun
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%files
%license COPYING
%doc README TODO
%{_bindir}/barcode
%{_bindir}/sample
%{_infodir}/%{name}.info%{?ext_info}

%files devel
%{_includedir}/barcode.h
%{_libdir}/libbarcode.a

%changelog
* Thu Jun 18 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Mon Sep  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Build using -ffat-lto-objects
- Run spec-cleaner
- Remove obsolete conditions and unneeded build requirements
- Fix the -devel package group
* Sat Dec 26 2015 mpluskal@suse.com
- Add gpg signature
- Tiny cleanup with spec-clener
* Sun May 17 2015 meissner@suse.com
- info deletion must be in %%preun
* Fri Nov 21 2014 malcolmlewis@opensuse.org
- Reintroduce devel package, header file needed for development of
  other packages, eg glabels.
- Add barcode-fix-renamed-include.patch: Fix renamed gettext
  include header reference.
- Spec and changes file tidy up.
* Sat Jan  4 2014 p.drouand@gmail.com
- Update to version 0.99:
  + Support for i18n.
  + Change license to GPLv3 or later version.
  + SVG support.
  + Added support for PCL output.
- Removed patchs fixed by upstream:
  + barcode-0.98.patch.
  + barcode-0.98-bookland.patch.
  + barcode-0.98-gcc_warning.patch.
  + barcode-0.98-memoryleak.patch.
  + barcode-0.98-nohtmltoinfo.patch.
- Adapt barcode-0.98-info.patch patch to upstream changes.
- Change license tag to GPL-3.0+ because of license change by
  upstream.
- Use %%configure instead of pass options "by-hand".
- Remove devel subpackage; it was already useless and upstream
  doesn't provide development files anymore.
- info file has to be provided with linked binary.
- Upstream doesn't provide any manpage anymore.
* Tue Jul 24 2012 werner@suse.de
- Build requires texinfo as well as makeinfo.
* Tue Jul 10 2012 werner@suse.de
- Make it build with latest TeXLive 2012 with new package layout.
* Tue Dec 20 2011 coolo@suse.com
- use original tar and apply previous patch.
* Thu Oct 15 2009 marek.belisko@open-nandra.com
- memory leak fixed (bnc#546020).
* Thu Sep 17 2009 mseben@novell.com
- added leak-fix.patch (bnc#537525).
* Fri Apr 11 2008 lmichnovic@suse.cz
- reenabled pdf creation, the ps2pdf is fixed now
  (*nohtmltoinfo.patch)
* Tue Apr  8 2008 lmichnovic@suse.cz
- fixed executable perm of info page.
- not removing RPM_BUILD_ROOT in %%install section.
* Tue Apr  8 2008 lmichnovic@suse.cz
- disabled generating html which was broken for a long time anyway
  and disabled pdf creation because broken ps2pdf
  (*nohtmltoinfo.patch).
* Fri Apr 20 2007 aj@suse.de
- Use texlive.
- Cleanup build requires.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires.
* Wed Sep 21 2005 lmichnovic@suse.cz
- fixed gcc warning.
* Fri Dec 10 2004 ro@suse.de
- use ghostscript-x11-packages in neededforbuild
* Sun Jan 11 2004 adrian@suse.de
- build as user.
* Thu Jun 19 2003 ltinkl@suse.cz
- updated sources to 0.98.
- install bookland.py script.
- correctly install info pages.
* Mon Apr  8 2002 pmladek@suse.cz
- used macro %%{_libdir} to fix for lib64.
- cleaned up spec file.
* Mon Jan  7 2002 rvasice@suse.cz
- update to version 0.97.
* Tue Jun  5 2001 rvasice@suse.cz
- initial package version 0.96.
- fixed paths in Makefile.in, added DESTDIR.
